LOGIN_ERROR = "Session login failed due '{}'. {} retries remaining"
SCRAPING_ERROR = "Scraping failed due '{}'"
SCRAPING_RESOLUTION_INFO = "The available events are {}"
SCRAPING_EMPTY_INFO = "There are any available event"
